/*************************************************************************************
Version: Oct. 2020
 
This code generates a dataset for the political contributions from Big-6 BMS producers and their parents:
"political_contributions.xlsx".

The steps taken in this code are as follows:

- Import data:
	Step 0: Import raw candidate data and save as dta.
			This will be used to link PACs to candidates data to check the party of candidates
	Step 1: Import raw committee data and save as dta.
			This will be used to link donors and receipients.
	Step 2: Import raw individual data and save as dta. 
			Keep necessary observations.
	Step 3: Import raw data for PAC to candidate
			Keep necessary observations.
	Step 4: PAC to PAC contributions.
			Keep necessary observations.

- Export the final dataset

- Create graphs

Note1:
Download Campaign Finance Data from https://www.opensecrets.org/bulk-data/downloads.
Campaign Finance Data from Open Secret dataset consist of 5 tables: 
candidates, FEC committees, individual contributions, PAC to candidates, and PAC to PACs.
Text fields are surrounded by pipe character (|), whereas numbers and dates are not.
To import the rawdata into Stata, users have to change all | to " before importing.
Detailed explanations on variables can be found in the Open Data User's Guide (https://www.opensecrets.org/resources/datadictionary/UserGuide.pdf)

Note2:
As of 10/11/2020, a file downloaded from the website on the contributions from PACs to PACs in 2008 (pac_others08.txt) is incomplete. 
We use the correct file (pac_others08_CRP.txt) that we received from the Center for Responsive Politics (Open Secret) upon our request.

************************************************************************************/

log using "$folder/log/contribution", replace


************* IMPORT RAW DATA***************************************************

*------------ Step 0: Candidates ----------------------------------------------*

/*
Link PACs with Candidate data to check candidates' parties and the status (winner/loser) of a candidate.
Also check if the expenditure goes directly to candidates.
Raw data include indirect expenditure for/against candidates.

Note: 
Candidates' types (parties, winner/loser/others) may change during an election cycle.
Raw data record all types that candidates had during the election cycle.
This implies that one ID can have multiple types.
Here, we extract candidate's party (Demo,Repub,Third,Switched) and status (Winner, Loser, Others) uniquely from mixed information
*/

foreach x in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	import delimited "$folder/src/cands`x'.txt", delimiter(comma) clear

	forvalues i = 1/12 {
		rename v`i' cands_v`i'
	}

	sort cands_v3
	rename cands_v3 CID		// Unique ID for candidates

	replace cands_v9="1" if cands_v9=="Y"		// Y if a candidate ever ran for the office during the election cycle
	destring cands_v9, replace
	gen dum=1
	collapse (first) cands_v6 (count) cands_v9 dum , by(CID cands_v11)		// cands_v6 indicates the type of election, cands_v11 is the type of candidate (Party + status)
	save "$folder/dta/c_temp`x'.dta", replace	

	collapse (first) cands_v6 (count) cands_v9 dum , by(CID)
	rename dum dum2 

	qui merge 1:m CID using "$folder/dta/c_temp`x'.dta", nogen

	gen keep=0
	replace keep=1 if dum2==1	// dum2>1 if status changed during the cycle

	save "$folder/dta/c_temp`x'.dta", replace

	keep if keep==1				// No problems with these observations. Separate these for a later use.
	save "$folder/dta/cc_temp`x'.dta", replace

	use "$folder/dta/c_temp`x'.dta", replace
	keep if keep==0				// There are more than two status for these obs.
	gen wl=-1 if (substr(cands_v11,2,2)=="L"|substr(cands_v11,2,2)=="W")	// Winner/Loser
	replace wl=0 if wl!=-1
	sort wl		// to make "L" and "W" appear before other status like "N"
	collapse (first) cands_v6 cands_v9 cands_v11 dum dum2 keep (sum)wl, by(CID)	// By summing up wl, we have 0(Drop out),-1(W or L),2(W or L with switching party)
	replace cands_v11="S"+substr(cands_v11,2,2) if wl!=-1	// "S" for switching party

	drop wl
	append using "$folder/dta/cc_temp`x'.dta"

	drop dum dum2 keep

	save "$folder/dta/cands`x'.dta", replace

	rm "$folder/dta/c_temp`x'.dta"
	rm "$folder/dta/cc_temp`x'.dta"

}


*------------ Step 1: Committee -----------------------------------------------*

/*
Import and save committee data.
It includes unique IDs of commitees (PACs, candidates): "CmteID".
Files created this step will be used later to identify who donors and recipients are.
*/

foreach x in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	import delimited "$folder/src/cmtes`x'.txt", delimiter(comma) clear

	forvalues i = 1/14 {
		rename v`i' cmtes_v`i'
	}

	sort cmtes_v2
	rename cmtes_v2 CmteID

	save "$folder/dta/cmtes`x'.dta", replace

}


*------------- Step 2: Individual Contribution --------------------------------*

/*
In this step, we create a dataset that contains individual contributions.

Overview:
1. Import raw data
2. Keep only relevant observations considering the type of transaction and M&A history
3. Drop irrelevant observations and standardize the name of organizations correcting spelling errors

*/


*** IMPORT RAW DATA OF INDIVIDUAL CONTRIBUTIONS ***

foreach x in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	import delimited "$folder/src/indivs`x'.txt", delimiter(comma) varnames(nonames) stringcols(3 4 5 6 7 8 9 12 13 14 15 16 17 18 19 20 21 22 23) clear
	save "$folder/dta/i`x'.dta", replace
}


*** KEEP ONLY BIG-6 BMS FIMRS AND THEIR PARENTS ***
/*  We only use infant formula manufacturers and their parent companies.
	To do so, we consider M&A history.
	We group infant formula manufacturers for a future reference
	1*: Abbott, 2*: Nestle(Gerber:Novartis-Nestle,Wyeth:Wyeth-Pfizer-Nestle), 3*: Mead Johnson(BMS-MJN-RB), 
	4*: Kraft Heinz(PM-Altria-Kraft, HJ Heinz), 5*: Danone(Numico), 6*: Perrigo(PBM)
*/

foreach x in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	use "$folder/dta/i`x'.dta", clear

	sort v17 
	rename v17 CmteID

* Group observations based on the name of firms. We utilize three variables to identify the name of firms:
	* v6 (Orgname)	: standardized name of the donor's employer
	* v7 (UltOrg)	: standardized name of the ultimate parent organization 
	* v22 (Employer): name of donor's employer from electronic filing
* Since there are many typos in indivual contributions, we start from broad phrase filters and drop irrelevant observations later.

	gen group=0	

	replace group=11 if strpos(v6,"Alere Inc")|strpos(v7,"Alere Inc")|strpos(v22,"Alere Inc")|strpos(v22,"ALERE INC")
	replace group=1 if v6=="Abbott Laboratories"|v7=="Abbott Laboratories"|strpos(v22,"Abbott Laboratories")|strpos(v22,"ABOTT LABORATORIES")|strpos(v22,"Abbott Labs")|strpos(v22,"ABOTT LABS")

	replace group=21 if strpos(v6,"Novartis AG")|strpos(v7,"Novartis AG")|strpos(v22,"Novartis AG")|strpos(v22,"NOVARTIS")
	replace group=22 if strpos(v6,"American Home Products")|strpos(v7,"American Home Products")|strpos(v22,"American Home Products")|strpos(v22,"AMERICAN HOME PRODUCTS")
	replace group=23 if strpos(v6,"Wyeth")|strpos(v7,"Wyeth")|strpos(v22,"Wyeth")|strpos(v22,"WYETH")
	replace group=24 if strpos(v6,"Pfizer Inc")|strpos(v7,"Pfizer Inc")|strpos(v22,"Pfizer")|strpos(v22,"PFIZER")
	replace group=25 if strpos(v6,"Gerber Products")|strpos(v7,"Gerber Products")|strpos(v22,"Gerber Products")|strpos(v22,"GERBER PRODUCTS")
	replace group=2 if v6=="Nestle SA"|v7=="Nestle SA"|strpos(v22, "Nestl?")|strpos(v22,"NESTL?")|strpos(v22, "Nestle")|strpos(v22,"NESTLE")

	replace group=31 if (strpos(v6,"Bristol")&strpos(v6,"Myers"))|(strpos(v7,"Bristol")&strpos(v7,"Myers"))|(strpos(v22,"Bristol")&strpos(v22,"Myers"))|(strpos(v22,"BRISTOL")&strpos(v22,"MYERS"))
	replace group=32 if strpos(v22,"Reckitt Benckiser")|strpos(v22,"RECKITT BENCKISER")|strpos(v6,"Reckitt Benckiser")|strpos(v7,"RECKITT BENCKISER")
	replace group=3 if strpos(v22, "Mead Johnson")|strpos(v22, "MEAD JOHNSON")|strpos(v6, "Mead Johnson")|strpos(v6, "MEAD JOHNSON")

	replace group=41 if strpos(v6,"HJ Heinz")|strpos(v7,"HJ Heinz")|(strpos(v22,"Heinz")&strpos(v22,"J")&strpos(v22,"H"))|(strpos(v22,"HEINZ")&strpos(v22,"J")&strpos(v22,"H"))
	replace group=42 if strpos(v6, "Kraft Foods")|strpos(v7,"Kraft Foods")|strpos(v22,"Kraft Foods")|strpos(v22,"KRAFT FOODS")
	replace group=43 if strpos(v6,"Philip Morris")|strpos(v7,"Philip Morris")|strpos(v22,"Philip Morris")|strpos(v22,"PHILIP MORRIS")|strpos(v6,"Altria Group")|strpos(v7,"Altria Group")|strpos(v22,"Altria Group")|strpos(v22,"ALTRIA GROUP")
	replace group=4 if strpos(v6,"Kraft Heinz")|strpos(v7,"Kraft Heinz")|strpos(v22,"Kraft Heinz")|strpos(v22,"KRAFT HEINZ")

	replace group=51 if strpos(v6, "Numico")|strpos(v7,"Numico")|strpos(v22,"Numico")|strpos(v22,"NUMICO")
	replace group=5 if strpos(v6, "Danone")|strpos(v7,"Danone")|strpos(v22, "Danone")|strpos(v22,"DANONE")

	replace group=61 if v6=="Pbm Holdings"|v7=="Pbm Holdings"|strpos(v22,"Pbm Holdings")|strpos(v22,"PBM HOLDINGS")
	replace group=6 if strpos(v6,"Perrigo")|strpos(v7,"Perrigo")|strpos(v22, "Perrigo")|strpos(v22, "PERRIGO")

	keep if group!=0

	* Add recipients' information (PACs and Candidates)
	qui merge m:1 CmteID using "$folder/dta/cmtes`x'.dta", keep(match master) nogen

	rename v5 CID
	qui merge m:1 CID using "$folder/dta/cands`x'.dta", keep(match master) nogen
	rename CID v5

	save "$folder/dta/indivs`x'.dta", replace
	rm "$folder/dta/i`x'.dta"
}

use "$folder/dta/indivs94.dta", clear
destring v10, replace
save "$folder/dta/indivs94.dta", replace

* Append separate files for each year into one

foreach y in "90" "92" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	append using "$folder/dta/indivs`y'.dta"
	compress
}

sort v1
drop v24 cmtes_v1

save "$folder/dta/indiv_all.dta", replace	// This intermediate file considers all-time contributions (parents are included even before mergers and after spinoffs).

*** KEEP RELEVANT OBSERVATIONS CONSIDERING TYPE OF CONTRIBUTIONS AND M&A HISTORY ***

/*
NOTE 1:
Open Secret's user's guide recommends common criteria when using indivs data.
Among them, we apply
1) Realcode not like Z9* (these are noncontributions);
2) Limit types to 10, 11, 15, 15E, 15J, 22Y;
3) RecipID like N* limits to candidates if necessary.
We don't apply the following criteria to include relevant observations
4) Source <> P/PAC excludes contributions to PACs other than leadership PACs;
5) Link to committees on cmteid to cmteid and set primcode to Not like z4* to exclude contributions to joint fund raising committees;
6) To limit to individuals: contribid not blank;
7) To exclude generic orgnames: source <> "GEN".

NOTE 2:
Since we are going to combine individuals' contributions and PACs' contributions based on firms, we have to be careful to avoid double counting.
Suppose Abbott's PAC gets money from their employees then turn around and give that money to others.
This results in double counting since both employees contributions to their PACs and contributions by Abbott's PAC will be counted.
In order to avoid this situation, we exclude individuals' contributions that go to their employer's PAC.
*/

gen use=0	// We use only relevant observations. Some are not contributions

replace use=1 if v16=="10 "|v16=="11 "|v16=="15 "|v16=="15E"|v16=="15e"|v16=="15J"|v16=="15j"|v16=="22Y"|v16=="22y"	// v16(Type) is the type of transaction
replace use=0 if v3==""	// v3(ContribID) is an ID for donor
replace use=0 if strpos(v8,"Z9")|strpos(v8,"z9")	// these are noncontributions
replace use=0 if strpos(cmtes_v5,"Abbott Laboratories")|strpos(cmtes_v5,"Nestle SA")|strpos(cmtes_v5,"Groupe Danone")|strpos(cmtes_v5,"Perrigo Co")|strpos(cmtes_v5,"Reckitt Benckiser Plc")|strpos(cmtes_v5,"Kraft Heinz")|strpos(cmtes_v5,"Kraft Foods")|strpos(cmtes_v5,"HJ Heinz")|strpos(cmtes_v5,"Philip Morris")|strpos(cmtes_v5,"Altria Group")|strpos(cmtes_v5,"Pfizer Inc")|strpos(cmtes_v5,"American Home Products")|strpos(cmtes_v5,"Wyeth")|strpos(cmtes_v5,"Novartis AG")|strpos(cmtes_v5,"Mead Johnson")|strpos(cmtes_v5,"Gerber Products")|strpos(cmtes_v5,"Bristol-Myers Squibb")|strpos(cmtes_v5,"Alere Inc")|strpos(cmtes_v5,"Coca-Cola")		// Remove contributions to own incorporate PACs

rename v# (Cycle FECTransID ContribID Contrib RecipID Orgname UltOrg RealCode date Amount Street City State Zip RecipCode Type OtherID Gender Microfilm Occupation Employer Source)
rename cmtes_v# (cmtes_PACShort cmtes_Affiliate cmtes_Ultorg cmtes_RecipID cmtes_RecipCode cmtes_FECCandID cmtes_Party cmtes_PrimCode cmtes_Source cmtes_Sensitive cmtes_Foreign cmtes_Active)
rename cands_v# (cands_DistIDRunFor cands_CycleCand cands_RecipCode)

gen Date=date(date,"MDY")
format Date %td 
drop date

*** Now, we consider the M&A history. We will drop, rename, or regroup observations based on the date of purchase, merger, acquition, or spinoff.

replace group=1 if group==11&(Date>td(3oct2017))	// Alere
replace use=0 if group==11
replace use=0 if group==21&(Date>td(12apr2007)|Date<td(26aug1994))	// Novartis
replace use=0 if group==21&strpos(Orgname,"Ciba")&(Date<td(07mar1996))	
replace group=21 if group==25&(Date>td(26aug1994))&(Date<td(12apr2007))	//Gerber to sandoz and Novartis
replace group=2 if group==25&(Date>td(12apr2007))						//Gerber to Nestle

replace group=23 if group==22&(Date>td(11mar2002))	// American Home Products
replace group=22 if group==23&(Date<td(11mar2002))
replace use=0 if group==23&(Date>td(15oct2009))	// Wyeth
replace use=0 if group==24&((Date<td(15oct2009)|Date>td(30nov2012)))	// Pfizer

replace group=31 if group==3&(Date<td(16nov2009))	// MJN - BMS
replace group=32 if group==3&(Date>td(15jun2017))	// MJN - RB
replace use=0 if group==31&(Date>td(16nov2009))	// BMS
replace use=0 if group==32&(Date<td(15jun2017))	// RB

replace group=4 if group==41&(Date>td(2jul2015))	// HJ Heinz
replace group=4 if group==42&(Date>td(2jul2015))	// Kraft Foods
replace use=0 if group==43&(Date>td(30mar2007))	// PM, Altria
replace group=5 if group==51&(Date>td(29nov2007))	// Numico
replace group=6 if group==61&(Date>td(3may2010))	// PBM

keep if use==1

*** Drop irrelevant obs. Check and correct spelling errors.

* Abbott
replace Orgname="Abbott Laboratories" if group==1&Orgname!="Abbott Laboratories"&UltOrg!="Abbott Laboratories"&(strpos(Employer, "ABOTT LAB")|strpos(Employer, "Abbott Lab"))
replace Orgname="St Jude Medical" if strpos(Orgname, "St Jude Medical")
replace Orgname="Alere Inc" if strpos(Orgname, "Alere Inc")
replace UltOrg="Abbott Laboratories" if group==1

* Perrigo
replace Orgname="Perrigo Co" if group==6&Orgname!="Perrigo Co"&UltOrg!="Perrigo Co"&(strpos(Orgname,"Perrigo Co")|strpos(Orgname,"Perrigo Inc")|strpos(Orgname,"Perrigo LLC")|Orgname=="Perrigo")
replace Orgname="Perrigo Co" if group==6&Orgname==""&(strpos(Employer,"Perrigo Co")|strpos(Employer,"PERRIGO CO")|strpos(Employer,"PERRIGO INC")|Employer=="PERRIGO"|Employer=="Perrigo")
replace use=0 if group==6&Orgname!="Perrigo Co"&UltOrg!="Perrigo Co"&(Orgname=="Perrigo & Kahle"|strpos(Orgname,"Gdk Construction"))
replace UltOrg="Perrigo Co" if group==6

* Danone
replace use=0 if group==5&UltOrg!="Groupe Danone"&(strpos(Orgname,"Simpson")|strpos(Orgname,"Danaher")|Orgname=="Danone Group")
replace Orgname="Danone Waters of America" if group==5&UltOrg!="Groupe Danone"&(strpos(Employer, "Danone Water")|strpos(Employer, "DANONE WATER")|strpos(Employer, "Danone Walter"))
replace Orgname="Danone North America" if group==5&UltOrg!="Groupe Danone"&(strpos(Employer, "DANONEWAVE")|Orgname=="Danone Na"|strpos(Employer, "DANONE NORTH")|strpos(Employer,"DANONEWARE"))
replace UltOrg="Groupe Danone" if group==5&Orgname!="Groupe Danone"

* Nestle: Nestle, Gerber, Wyeth
replace Orgname="Novartis Phamaceuticals" if group==21&UltOrg!="Novartis AG"&(strpos(Orgname, "maceuticals")|strpos(Employer,"PHARMA"))
replace Orgname="Novartis Crop Protection" if group==21&UltOrg!="Novartis AG"&(strpos(Employer, "Crop Protection")|strpos(Employer, "CROP PROTECTION"))
replace Orgname="Novartis Institutes for Biomed Research" if group==21&UltOrg!="Novartis AG"&strpos(Employer, "INST BIOM")
replace Orgname="Novartis Seeds" if group==21&UltOrg!="Novartis AG"&(strpos(Employer, "SEEDS")|strpos(Employer,"Seeds"))
replace Orgname="Novartis Oncolocy" if group==21&UltOrg!="Novartis AG"&(strpos(Employer, "Oncology")|strpos(Employer,"ONCOLOGY"))
replace Orgname="Novartis Consumer Health" if group==21&UltOrg!="Novartis AG"&(strpos(Employer, "CONSUMER HEALTH")|strpos(Employer,"Consumer Health"))
replace Orgname="Gerber Products Co" if group==21&Orgname=="Gerber Products"|Employer=="GERBER PRODUCTS COMPANY"
replace UltOrg="Novartis AG" if group==21&UltOrg==""

replace Orgname="American Home Products" if group==22&Orgname!="American Home Products"&UltOrg!="American Home Products"&(strpos(Employer,"AMERICAN HOME PRODUCTS")|strpos(Employer,"American Home Products"))
replace use=0 if group==22&(Orgname=="Dwyer & White"|Orgname=="Wyeth Dairy"|Orgname=="Edi Wyeth"|strpos(Orgname,"Windsor, Wyeth & Ward")|strpos(Orgname,"Philadelphia Main")|strpos(Employer,"DAIRY")|strpos(Employer,"WYETH-BYER"))
replace Orgname="Wyeth-Lederle Vaccines" if group==22&strpos(Employer,"WYETHLEDERLE")
replace Orgname="Wyeth" if group==22&(strpos(Employer,"WYETH")&strpos(Employer,"AYERST"))|strpos(Employer,"Wyeth/")|strpos(Employer,"GENETICS")
replace UltOrg="American Home Products" if group==22

replace Orgname="Wyeth" if group==23&(Orgname=="American Home Products"|Employer=="Wyeth"|Employer=="WYETH"|strpos(Employer,"Wyeth/")|strpos(Employer,"AMERICAN HOME PRODUCTS"))|strpos(Employer,"PEARL RIVER")
replace use=0 if group==23&(Orgname=="Dwyer & White"|Orgname=="Wyeth Dairy"|Orgname=="Edi Wyeth"|strpos(Orgname,"Windsor, Wyeth & Ward")|strpos(Orgname,"Philadelphia Main")|strpos(Employer,"DAIRY")|strpos(Employer,"WYETH-BYER"))
replace Orgname="Wyeth Research" if group==23&UltOrg!="Wyeth"&strpos(Employer,"WYETH RESEARCH")
replace Orgname="Wyeth Phamaceuticals" if group==23&UltOrg!="Wyeth"&strpos(Employer,"WYETH PHARMA")
replace Orgname="Wyeth Bio Pharmaceuticals" if group==23&UltOrg!="Wyeth"&strpos(Orgname,"Bio")&(strpos(Orgname,"pharma")|strpos(Orgname,"Pharma"))
replace UltOrg="Wyeth" if group==23

replace Orgname="Pfizer Inc" if group==24&((strpos(Employer,"PFIZER")&strpos(Employer,"INC"))|Employer=="PFIZER"|Employer=="Pfizer"|Employer=="Pfizer Inc")
replace Orgname="Pfizer Consumer Healthcare" if group==24&strpos(Employer,"Healthcare")
replace Orgname="Pfizer Animal Health" if group==24&strpos(Employer,"ANIMAL HEALTH")
replace Orgname="Pfizer Strategic Investment Group" if group==24&Employer=="PFIZER STRATEGIC INVESTMENTS GROUP"
replace UltOrg="Pfizer Inc" if group==24

replace use=0 if group==25&strpos(Orgname,"Plumbing")
replace UltOrg="Gerber Products Co" if group==25

replace Orgname="Nestle USA" if group==2&(strpos(Employer, "Nestle U")|strpos(Employer, "NESTLE U")|Orgname=="Nestle Usa"|strpos(Employer, "NESTLE' USA")|strpos(Employer, "NESTLE  USA"))
replace Orgname="Nestle Purina PetCare" if group==2&(strpos(Employer, "NESTLE PURINA")|strpos(Employer, "Nestle Purina")|strpos(Orgname,"Nestle Purina")|strpos(Employer, "PURINA PET")|strpos(Employer, "Purina Pet")|strpos(Employer, "NESTLE PURLNA"))
replace Orgname="Nestle Waters North America" if group==2&(strpos(Employer, "NESTLE WATER")|strpos(Employer, "Nestle Waters")|strpos(Orgname,"Nestle Water")|strpos(Orgname, "Nestl? Water")|strpos(Employer, "NESTL? WATER"))
replace Orgname="Dreyer's Grand Ice Cream" if group==2&(strpos(Employer, "Dreyer's")|strpos(Employer, "DREYER'S")|strpos(Orgname,"Dreyer's Grand")|strpos(Orgname, "Dreyers")|strpos(Employer, "DRYER'S"))
replace Orgname="Nestle SA" if group==2&strpos(Orgname, "Nestle Sa")|strpos(Employer, "NESTLE S.A.")
replace Orgname="Nestle Professional" if group==2&(strpos(Employer, "NESTLE PROFESSIONAL")|strpos(Employer, "Nestle Professional"))
replace Orgname="Nestle Confections & Snacks" if group==2&(strpos(Employer, "NESTLE CONFECTIONS")|strpos(Employer, "Nestle Confections"))
replace Orgname="Nestle R&D Marysville" if group==2&(strpos(Employer, "Marysville")|strpos(Employer,"MARYSVILLE"))
replace Orgname="Nestle Ptc Marysville" if group==2&(strpos(Orgname, "Nestle Ptc")|strpos(Employer,"MARRYSVILLE"))
replace Orgname="Gerber Products Co" if group==2&(strpos(Employer, "GERBER")|strpos(Employer,"Gerber"))
replace Orgname="Coca-Cola Nestle Refreshments" if group==2&(Date<td(30jan2001))&(strpos(Employer, "Coca-Cola")| strpos(Employer, "COCA-COLA")|strpos(Employer, "Coca Cola")|strpos(Employer, "COCA COLA"))
replace Orgname="Beverage Partners Worldwide" if group==2&(Date>td(29jan2001))&(strpos(Employer, "Coca-Cola")| strpos(Employer, "COCA-COLA")|strpos(Employer, "Coca Cola")|strpos(Employer, "COCA COLA")|strpos(Employer, "BEVERAGE COMPANY"))
replace UltOrg="Nestle SA" if group==2&(Orgname=="Nestle USA"|Orgname=="Nestle Purina PetCare"|Orgname=="Nestle Waters North America"|Orgname=="Dreyer's Grand Ice Cream"|Orgname=="Nestle Professional"|Orgname=="Nestle Confections & Snacks"|Orgname=="Nestle R&D Marysville"|Orgname=="Nestle Ptc Marysville"|Orgname=="Nestle SA"|Orgname=="Gerber Products Co"|Employer=="NESTLE"|Orgname=="Beverage Partners Worldwide"|strpos(Orgname,"Coca-Cola")|Orgname=="Nestle Business Services"|Employer=="Nestle"|strpos(Orgname,"Nestle Health Science"))
replace use=0 if group==2&(strpos(Employer,"Nestler")|strpos(Orgname,"Nestler")|strpos(Orgname,"Stone & Lime")|strpos(Employer,"Stone & Lime")|strpos(Orgname,"Chugach")|strpos(Employer,"ANESTLE")|strpos(Orgname,"Batchis")|strpos(Employer,"LIDEN"))
replace use=0 if group==2&UltOrg!="Nestle SA"

* MJN, BMS, RB
replace Orgname="Mead Johnson Nutrition" if group==3&(strpos(Orgname,"Mead Johnson")|strpos(Employer,"MEAD JOHNSON"))
replace UltOrg="Mead Johnson Nutrition" if group==3
replace Orgname="Bristol-Myers Squibb" if group==31&((strpos(Employer,"BRISTOL")&strpos(Employer,"MYERS"))|(strpos(Employer,"Bristol")&strpos(Employer,"Myers")))
replace UltOrg="Bristol-Myers Squibb" if group==31
replace UltOrg="Reckitt Benckiser Plc" if group==32

* Kraft Heinz, PM, Altria
replace use=0 if group==41&(strpos(Employer,"JOHN HEINZ")|strpos(Employer,"PJ HEINZ")|strpos(Employer,"HOFHEINZ")|strpos(Employer,"CLIFFORD")|strpos(Employer,"HEINZEL")|strpos(Orgname,"Progressive")|strpos(Orgname,"Steelers"))
replace Orgname="HJ Heinz Co" if group==41&(Employer=="H.J. HEINZ"|Employer=="H. J. HEINZ"|Employer=="H. J. HEINZ CO."|Employer=="HJ HEINZ CO"|Orgname=="JH Heinz Co"|strpos(Orgname,"HJ Heinz Co")|Employer=="H J HEINZ COMPANY")
replace UltOrg="HJ Heinz Co" if group==41

replace use=0 if group==42&(strpos(Orgname,"Concordia")|strpos(Orgname,"Mondelez"))
replace Orgname="Kraft Foods" if group==42&(Employer=="KRAFT FOODS"|strpos(Employer,"KRAFT FOODS INC")|strpos(Employer,"KRAFT FOODS, INC.")|strpos(Employer,"Kraft Foods Inc."))
replace Orgname="Kraft Foods" if group==42&Orgname=="Retired"&strpos(Employer,"KRAFT FOODS")
replace Orgname="Kraft Foods" if group==42&Orgname==""&strpos(Employer,"KRAFT FOODS/")
replace Orgname="Kraft Foods North America" if group==42&(strpos(Employer,"NORTH AMERICA")|strpos(Employer,"N.A."))
replace Orgname="Kraft Foods Global" if group==42&strpos(Employer,"GLOBAL")
replace Orgname="Kraft Foods Group" if group==42&(strpos(Employer,"KRAFT FOODS GROUP")|strpos(Employer,"KRAFT FOODS, BA"))&(Date>td(1oct2012))
replace Orgname="Kraft Foodservice" if group==42&(strpos(Employer, "KRAFT FOODSERVICE"))
replace Orgname="Kraft Foods Federal Credit Union" if group==42&strpos(Employer, "Credit Union")
replace Orgname="Kraft Foods" if group==42&Orgname==""&strpos(Employer,"KRAFT FOODS")
replace group=43 if group==42&(Date<td(30mar2007))
replace UltOrg="Kraft Foods" if group==42&(Date<td(1oct2012))
replace UltOrg="Kraft Foods Group" if group==42&(Date>td(1oct2012))

replace use=0 if group==43&strpos(Orgname,"Rector")
replace Orgname="Philip Morris" if group==43&(Employer=="PHILIP MORRIS"|strpos(Employer,"PHILIP MORRIS INC")|strpos(Employer,"PHILIP MORRIS COMP")|strpos(Employer,"Philip Morris Co")|Orgname=="Philip Morris Companies")
replace Orgname="Philip Morris USA" if group==43&(Employer=="PHILIP MORRIS USA"|strpos(Employer,"Philip Morris USA")|strpos(Orgname,"Philip Morris USA"))
replace UltOrg="Philip Morris" if group==43&strpos(Orgname,"Kraft")&(Date<td(27jan2003))
replace UltOrg="Altria Group" if group==43&strpos(Orgname,"Kraft")&(Date>td(26jan2003))
replace Orgname="Philip Morris USA" if group==43&(Date<td(26jan2003))&(strpos(Employer,"Morris Management")|strpos(Employer,"MORRIS MANAGEMENT")|strpos(Employer,"MORRIS MGT")|strpos(Employer,"MORRIS MGMT")|strpos(Employer,"Morris Mgt"))
replace Orgname="Altria Group" if group==43&(Date>td(26jan2003))&(strpos(Employer,"Morris Management")|strpos(Employer,"MORRIS MANAGEMENT")|strpos(Employer,"MORRIS MGT")|strpos(Employer,"MORRIS MGMT")|strpos(Employer,"Morris Mgt")|strpos(Employer,"ALTRIA GROUP"))
replace Orgname="Philip Morris International" if group==43&Employer=="PHILIP MORRIS INT'L"
replace Orgname="Philip Morris Capital" if group==43&Employer=="PHILIP MORRIS CAPITAL CORPORATION"
replace UltOrg="Philip Morris" if group==43&(Date<td(27jan2003))
replace UltOrg="Altria Group" if group==43&(Date>td(26jan2003))

replace use=0 if group==4&(strpos(Employer,"JOHN HEINZ")|strpos(Employer,"PJ HEINZ")|strpos(Employer,"HOFHEINZ")|strpos(Employer,"CLIFFORD")|strpos(Employer,"HEINZEL")|strpos(Orgname,"Progressive")|strpos(Orgname,"Prog Care")|strpos(Orgname,"Pittsburgh"))
replace Orgname="Kraft Foods Group" if group==4&(Employer=="KRAFT FOODS"|strpos(Employer,"KRAFT FOODS INC")|strpos(Employer,"KRAFT FOODS, INC")|strpos(Employer,"Kraft Foods Inc."))
replace Orgname="Kraft Foods North America" if group==4&(strpos(Employer,"FOODS NORTH AMERICA")|strpos(Employer,"FOODS N.A."))
replace Orgname="Kraft Foods Global" if group==4&strpos(Employer,"FOODS GLOBAL")
replace Orgname="Oscar Mayer" if group==4&strpos(Employer,"OSCAR MAYER")
replace Orgname="Kraft Foods Group" if group==4&Orgname=="Retired"&strpos(Employer,"KRAFT FOODS")
replace UltOrg="Kraft Heinz Co" if group==4

keep if use==1

gen Quarter=qofd(Date)
format Quarter %tq

gen cand=0
replace cand=1 if strpos(RecipID,"N")		// These are contributions to candidates

* Group and give name
gen Group=""
replace Group="Abbott" if group==1|group==11
replace Group="Nestle(Gerber,Wyeth)" if group==2|group==21|group==22|group==23|group==24|group==25
replace Group="RB(Mead Johnson)" if group==3|group==31|group==32
replace Group="Kraft Heinz" if group==4|group==41|group==42|group==43
replace Group="Danone" if group==5|group==51
replace Group="Perrigo" if group==6|group==61

order Cycle Quarter Date Orgname UltOrg Group Employer Occupation Amount, first
save "$folder/dta/indivs.dta", replace


*---------------- Step 3: PACs to Candidates ----------------------------------*
/*
In this step we create a dataset that consists contributions from relevant PACs to candidates.
It is similar to Step 2.

Overview:
1. Import raw data
2. Keep only relevant observations considering the type of transaction and M&A history
3. Drop irrelevant observations and standardize the name of organizations correcting spelling errors

*/

foreach x in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	import delimited "$folder/src/pacs`x'.txt", delimiter(comma) clear

	sort v3
	rename v3 CmteID

	qui merge m:1 CmteID using "$folder/dta/cmtes`x'.dta", keep(match master) nogen

	sort v4
	rename v4 CID

	qui merge m:1 CID using "$folder/dta/cands`x'.dta", keep(match master) nogen
	gen group=0

* We group infant formula manufacturers for a future reference
* 1*: Abbott, 2*: Nestle(Gerber:Novartis-Nestle,Wyeth:Wyeth-Pfizer-Nestle), 3*: Mead Johnson(BMS-MJN-RB), 4*: Kraft Heinz(PM-Altria-Kraft, HJ Heinz), 5*: Danone(Numico), 6*: Perrigo(PBM)
* First, we include necessary observations by name. Then, we filter out by date.

	replace group=11 if strpos(cmtes_v5,"Alere Inc")
	replace group=1 if strpos(cmtes_v5,"Abbott Laboratories")
	replace group=21 if strpos(cmtes_v5,"Novartis AG")
	replace group=22 if strpos(cmtes_v5,"American Home Products")
	replace group=23 if strpos(cmtes_v5,"Wyeth")
	replace group=24 if strpos(cmtes_v5,"Pfizer Inc")
	replace group=25 if strpos(cmtes_v5,"Gerber Products")
	replace group=2 if strpos(cmtes_v5,"Nestle SA")
	replace group=31 if strpos(cmtes_v5,"Bristol-Myers")
	replace group=32 if strpos(cmtes_v5,"Reckitt Benckiser Plc")
	replace group=3 if strpos(cmtes_v5, "Mead Johnson")
	replace group=41 if strpos(cmtes_v5,"HJ Heinz Co")
	replace group=42 if strpos(cmtes_v5, "Kraft Foods")
	replace group=43 if strpos(cmtes_v5,"Philip Morris")|strpos(cmtes_v5,"Altria Group")
	replace group=4 if strpos(cmtes_v5,"Kraft Heinz")
	replace group=51 if strpos(cmtes_v5, "Numico")
	replace group=5 if strpos(cmtes_v5, "Danone")
	replace group=61 if strpos(cmtes_v5,"Pbm Holdings")
	replace group=6 if strpos(cmtes_v5,"Perrigo")

	replace group=0 if strpos(v7,"Z9")|strpos(v7,"z9")|strpos(v7,"Z4")|strpos(v7,"z4")	// these are noncontributions

	keep if group!=0
	save "$folder/dta/pacs`x'.dta", replace
}

foreach y in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" {

	append using "$folder/dta/pacs`y'.dta", force
	compress
}

sort v1
drop cmtes_v1

gen use=0
replace use=1 if strpos(CID,"N")	// Limit contributions to candidates to make sure. (PAC to PAC is considered later)

rename v# (Cycle FECRecNo Amount date RealCode Type DI FECCandID)
rename cmtes_v# (cmtes_PACShort cmtes_Affiliate cmtes_Ultorg cmtes_RecipID cmtes_RecipCode cmtes_FECCandID cmtes_Party cmtes_PrimCode cmtes_Source cmtes_Sensitive cmtes_Foreign cmtes_Active)
rename cands_v# (DistIDRunFor CycleCand RecipCode)

gen Date=date(date,"MDY")
format Date %td 
drop date
gen Quarter=qofd(Date)
format Quarter %tq

* Regroup, rename, or drop observations by date.

replace group=1 if group==11&(Date>td(3oct2017))	// Alere
replace use=0 if group==11

replace use=0 if group==21&(Date>td(12apr2007)|Date<td(26aug1994))	// Novartis
replace use=0 if group==21&strpos(cmtes_PACShort,"Ciba")&(Date<td(07mar1996))	
replace group=21 if group==25&(Date>td(26aug1994))&(Date<td(12apr2007))	//Gerber to sandoz and Novartis
replace group=2 if group==25&(Date>td(11apr2007))						//Gerber to Nestle

replace group=23 if group==22&(Date>td(11mar2002))	// American Home Products
replace group=22 if group==23&(Date<td(11mar2002))
replace use=0 if group==23&(Date>td(15oct2009))	// Wyeth
replace use=0 if group==24&((Date<td(15oct2009)|Date>td(30nov2012)))	// Pfizer

replace group=31 if group==3&(Date<td(16nov2009))	// MJN - BMS
replace group=32 if group==3&(Date>td(15jun2017))	// MJN - RB
replace use=0 if group==31&(Date>td(16nov2009))	// BMS
replace use=0 if group==32&(Date<td(15jun2017))	// RB

replace group=4 if group==41&(Date>td(2jul2015))	// HJ Heinz - KH
replace group=4 if group==42&(Date>td(2jul2015))	// Kraft Foods - KH
replace group=43 if group==42&(Date<td(30mar2007))	// KF - Altria
replace use=0 if group==43&(Date>td(30mar2007))	// PM, Altria
replace group=5 if group==51&(Date>td(29nov2007))	// Numico
replace group=6 if group==61&(Date>td(3may2010))	// PBM

replace cmtes_Ultorg="Kraft Foods" if group==42&(Date<td(1oct2012))
replace cmtes_Ultorg="Kraft Foods Group" if group==42&(Date>td(1oct2012))
replace cmtes_Ultorg="Philip Morris" if group==43&(Date<td(27jan2003))
replace cmtes_Ultorg="Altria Group" if group==43&(Date>td(26jan2003))

keep if use==1

gen Group=""
replace Group="Abbott" if group==1|group==11
replace Group="Nestle(Gerber,Wyeth)" if group==2|group==21|group==22|group==23|group==24|group==25
replace Group="RB(Mead Johnson)" if group==3|group==31|group==32
replace Group="Kraft Heinz" if group==4|group==41|group==42|group==43
replace Group="Danone" if group==5|group==51
replace Group="Perrigo" if group==6|group==61

drop if DI=="I"		// drop indirect contributions for/against candidates. Only one observation drops.
save "$folder/dta/pacs.dta", replace

*--------------- Step 4: PACs to PACs -----------------------------------------*

/*
This step generates a dataset that contains contributions from BMS PACs to all other PACs

Note 1:
Open Secret's user's guide recommends several criteria.
Among them, we apply
1) Limit types(v22) to 24K, 22Z, 24R, 24Z;
2) To include recipprimcode(v17) like Z5* for contributions to party committees;
3) To include recipprimcode(v17) like j2* for contributions to leadership PACs.

*/

foreach x in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	import delimited "$folder/src/pac_other`x'.txt", delimiter(comma) clear

	sort v3
	rename v3 CmteID

	gen use=0	
	replace use=1 if (v22=="24K"|v22=="22Z"|v22=="24R"|v22=="24Z"|v22=="24k"|v22=="22z"|v22=="24r"|v22=="24z")&(strpos(v17,"Z5")|strpos(v17,"Z1")|strpos(v17,"J2")|strpos(v17,"z5")|strpos(v17,"z1")|strpos(v17,"j2"))
	keep if use==1

	qui merge m:1 CmteID using "$folder/dta/cmtes`x'.dta", keep(match master)

	sort v13
	rename v13 CID

	qui merge m:1 CID using "$folder/dta/cands`x'.dta", keep(match master) nogen
	rename CID v13

	gen group=0

	replace group=11 if strpos(cmtes_v5,"Alere Inc")
	replace group=1 if strpos(cmtes_v5,"Abbott Laboratories")
	replace group=21 if strpos(cmtes_v5,"Novartis AG")
	replace group=22 if strpos(cmtes_v5,"American Home Products")
	replace group=23 if strpos(cmtes_v5,"Wyeth")
	replace group=24 if strpos(cmtes_v5,"Pfizer Inc")
	replace group=25 if strpos(cmtes_v5,"Gerber Products")
	replace group=2 if strpos(cmtes_v5,"Nestle SA")
	replace group=31 if strpos(cmtes_v5,"Bristol-Myers")
	replace group=32 if strpos(cmtes_v5,"Reckitt Benckiser Plc")
	replace group=3 if strpos(cmtes_v5, "Mead Johnson")
	replace group=41 if strpos(cmtes_v5,"HJ Heinz Co")
	replace group=42 if strpos(cmtes_v5, "Kraft Foods")
	replace group=43 if strpos(cmtes_v5,"Philip Morris")|strpos(cmtes_v5,"Altria Group")
	replace group=4 if strpos(cmtes_v5,"Kraft Heinz")
	replace group=51 if strpos(cmtes_v5, "Numico")
	replace group=5 if strpos(cmtes_v5, "Danone")
	replace group=61 if strpos(cmtes_v5,"Pbm Holdings")
	replace group=6 if strpos(cmtes_v5,"Perrigo")

	replace group=0 if strpos(v17,"Z9")|strpos(v17,"z9")	// these are noncontributions
	keep if group!=0

	save "$folder/dta/pac_other`x'.dta", replace
}

* Since raw data omit 2008 data (10.11.2020),
* We use Correct pac_other08_CRP.txt that CRP sent us before they correct the raw data

import delimited "$folder/src/pac_other08_CRP.txt", delimiter(tab) varnames(nonames) numericcols(1) clear
replace v1=2008
sort v3
rename v3 CmteID

gen use=0	// We focus on contributions not receipts
replace use=1 if (v22=="24K"|v22=="22Z"|v22=="24R"|v22=="24Z"|v22=="24k"|v22=="22z"|v22=="24r"|v22=="24z")&(strpos(v17,"Z5")|strpos(v17,"Z1")|strpos(v17,"J2")|strpos(v17,"z5")|strpos(v17,"z1")|strpos(v17,"j2"))
keep if use==1

split v11, generate(new) parse(-)
split new3, generate(newnew)
drop v11
egen v11=concat(new2 newnew1 new1), punct(/)
drop new1 new2 new3 newnew1 newnew2
qui merge m:1 CmteID using "$folder/dta/cmtes08.dta", keep(match master)

sort v13
rename v13 CID

qui merge m:1 CID using "$folder/dta/cands08.dta", keep(match master) nogen
rename CID v13

gen group=0

replace group=11 if strpos(cmtes_v5,"Alere Inc")
replace group=1 if strpos(cmtes_v5,"Abbott Laboratories")
replace group=21 if strpos(cmtes_v5,"Novartis AG")
replace group=22 if strpos(cmtes_v5,"American Home Products")
replace group=23 if strpos(cmtes_v5,"Wyeth")
replace group=24 if strpos(cmtes_v5,"Pfizer Inc")
replace group=25 if strpos(cmtes_v5,"Gerber Products")
replace group=2 if strpos(cmtes_v5,"Nestle SA")
replace group=31 if strpos(cmtes_v5,"Bristol-Myers")
replace group=32 if strpos(cmtes_v5,"Reckitt Benckiser Plc")
replace group=3 if strpos(cmtes_v5, "Mead Johnson")
replace group=41 if strpos(cmtes_v5,"HJ Heinz Co")
replace group=42 if strpos(cmtes_v5, "Kraft Foods")
replace group=43 if strpos(cmtes_v5,"Philip Morris")|strpos(cmtes_v5,"Altria Group")
replace group=4 if strpos(cmtes_v5,"Kraft Heinz")
replace group=51 if strpos(cmtes_v5, "Numico")
replace group=5 if strpos(cmtes_v5, "Danone")
replace group=61 if strpos(cmtes_v5,"Pbm Holdings")
replace group=6 if strpos(cmtes_v5,"Perrigo")

replace group=0 if strpos(v17,"Z9")|strpos(v17,"z9")	// these are noncontributions
keep if group!=0

save "$folder/dta/pac_other08.dta", replace

use "$folder/dta/pac_other18.dta", clear

foreach y in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" {

	append using "$folder/dta/pac_other`y'.dta", force
	compress
}
sort v1

drop use cmtes_v1 _merge

rename v# (Cycle FECRecNo DonorCmte ContribLendTrans City State Zip FECOccEmp Primcode date Amount RecipID Party Otherid RecipCode RecipPrimcode Amend Report PG Microfilm Type RealCode Source)
rename cmtes_v# (cmtes_PACShort cmtes_Affiliate cmtes_Ultorg cmtes_RecipID cmtes_RecipCode cmtes_FECCandID cmtes_Party cmtes_PrimCode cmtes_Source cmtes_Sensitive cmtes_Foreign cmtes_Active)
rename cands_v# (DistIDRunFor CycleCand cand_RecipCode)

gen Date=date(date,"MDY")
format Date %td 
drop date
gen Quarter=qofd(Date)
format Quarter %tq

gen use=1
replace group=1 if group==11&(Date>td(3oct2017))	// Alere
replace use=0 if group==11
replace use=0 if DonorCmte=="Alere Inc"&(Date<td(3oct2017))

replace use=0 if group==21&(Date>td(12apr2007)|Date<td(26aug1994))	// Novartis
replace use=0 if group==21&strpos(cmtes_PACShort,"Ciba")&(Date<td(07mar1996))	
replace group=21 if group==25&(Date>td(26aug1994))&(Date<td(12apr2007))	//Gerber to sandoz and Novartis
replace group=2 if group==25&(Date>td(11apr2007))						//Gerber to Nestle

replace group=23 if group==22&(Date>td(11mar2002))	// American Home Products
replace group=22 if group==23&(Date<td(11mar2002))
replace use=0 if group==23&(Date>td(15oct2009))	// Wyeth
replace use=0 if group==24&((Date<td(15oct2009)|Date>td(30nov2012)))	// Pfizer

replace group=31 if group==3&(Date<td(16nov2009))	// MJN - BMS
replace group=32 if group==3&(Date>td(15jun2017))	// MJN - RB
replace use=0 if group==31&(Date>td(16nov2009))	// BMS
replace use=0 if group==32&(Date<td(15jun2017))	// RB

replace group=4 if group==41&(Date>td(2jul2015))	// HJ Heinz - KH
replace group=4 if group==42&(Date>td(2jul2015))	// Kraft Foods - KH
replace group=43 if group==42&(Date<td(30mar2007))	// KF - Altria
replace use=0 if group==43&(Date>td(30mar2007))	// PM, Altria
replace group=5 if group==51&(Date>td(29nov2007))	// Numico
replace group=6 if group==61&(Date>td(3may2010))	// PBM

replace cmtes_Ultorg="Kraft Foods" if group==42&(Date<td(1oct2012))
replace cmtes_Ultorg="Kraft Foods Group" if group==42&(Date>td(1oct2012))
replace cmtes_Ultorg="Philip Morris" if group==43&(Date<td(27jan2003))
replace cmtes_Ultorg="Altria Group" if group==43&(Date>td(26jan2003))

keep if use==1

gen Group=""
replace Group="Abbott" if group==1|group==11
replace Group="Nestle(Gerber,Wyeth)" if group==2|group==21|group==22|group==23|group==24|group==25
replace Group="RB(Mead Johnson)" if group==3|group==31|group==32
replace Group="Kraft Heinz" if group==4|group==41|group==42|group==43
replace Group="Danone" if group==5|group==51
replace Group="Perrigo" if group==6|group==61

save "$folder/dta/pac_other.dta", replace

*** Removing individual-year-table dataset

foreach x in "90" "92" "94" "96" "98" "00" "02" "04" "06" "08" "10" "12" "14" "16" "18"{

	rm "$folder/dta/pac_other`x'.dta"
	rm "$folder/dta/cands`x'.dta"
	rm "$folder/dta/cmtes`x'.dta"
	rm "$folder/dta/indivs`x'.dta"
	rm "$folder/dta/pacs`x'.dta"

}


************************* EXPORT THE FINAL DATASET *************************************

* 1. Collapse dataset to compute total contributions by BMS firms, elections, parties, and more

*** Individual contributions

use "$folder/dta/indivs.dta", replace
gen election=substr(cands_DistIDRunFor, 3,4)
replace election="PR" if election=="ES"		// Presidential election
replace election="SE" if election=="S1"|election=="S2"		// Senate
replace election="HR" if election!="PR"&election!="SE"&election!=""		// House of Representative

collapse (sum) Amount, by(Quarter cand Group RecipCode election)

la var Amount "contribution (USD)"
la var Quarter "quarter"
la var cand "flow of contribution: 0=goes to another PAC, 1=goes directly to a candidate"
la var Group "infant formula manufacturers"
la var RecipCode "code for recipient"
la var election "type of candidate: HR=House of Rep, SE=Senate, PR=President"

compress
save "$folder/dta/ind_collapse_quarter.dta",replace

*** Merge PAC to candidates and PAC to PAC file

use "$folder/dta/pacs.dta", clear
gen election=substr(DistIDRunFor, 3,4)
replace election="PR" if election=="ES"
replace election="SE" if election=="S1"|election=="S2"
replace election="HR" if election!="PR"&election!="SE"&election!=""

collapse (sum) Amount, by(Quarter Group RecipCode election)
gen cand=1		// contributions to candidates
save "$folder/dta/pacs_collapse_quarter.dta",replace

use "$folder/dta/pac_other.dta", clear
gen election=substr(DistIDRunFor, 3,4)
replace election="PR" if election=="ES"
replace election="SE" if election=="S1"|election=="S2"
replace election="HR" if election!="PR"&election!="SE"&election!=""

gen cand=0
replace cand=1 if strpos(RecipID, "N")	
collapse (sum) Amount (max) cand, by(Quarter Group RecipCode)

append using "$folder/dta/pacs_collapse_quarter.dta"
gen pac=1		// contributions by PACs

la var Amount "contribution (USD)"
la var cand "flow of contribution: 0=goes to another PAC, 1=goes directly to a candidate"
la var Quarter "quarter"
la var Group "infant formula manufacturers"
la var RecipCode "code for recipient"

compress
save "$folder/dta/pacs_contribution_quarter.dta",replace

rm "$folder/dta/pacs_collapse_quarter.dta"

*** Merge Individual contributions and PAC's contributions to generate total contributions

use "$folder/dta/pacs_contribution_quarter.dta", clear
append using "$folder/dta/ind_collapse_quarter.dta"
replace pac=0 if pac!=1
gen Year=yofd(dofq(Quarter))
gen quarter = string(Quarter, "%tq")
gen Pac="by PACs"
replace Pac="by Individuals" if pac==0
gen Cand="to Candidates"
replace Cand="to PACs" if cand==0
gen Party=substr(RecipCode,1,1)		// The first letter of RecipCode indicates party. The second letter indicates the status (winner, loser, others)
gen Status=substr(RecipCode,2,2)
drop if RecipCode==""

*** Save main dataset of political contributions

la var Year "year"
la var quarter "quarter"
la var Group "infant formula manufacturers"
la var Amount "contribution (USD)"
la var pac "type of contribution: 0=made by an employee, 1=made by a PAC"
la var cand "flow of contribution: 0=goes to another PAC, 1=goes directly to a candidate"
la var election "type of candidate: HR=House of Rep, SE=Senate, PR=President"
la var RecipCode "code for recipient"
la var Party "political party"
la var Status "status of candidate"

compress
save "$folder/dta/tot_contribution_quarter.dta",replace
export excel Year quarter Group Amount pac cand election RecipCode Party Status using "$folder/out/political_contributions.xlsx", sheet("data") firstrow(variables) replace

collapse (sum) Amount, by(Year Group)
export excel Year Group Amount using "$folder/out/political_contributions.xlsx", sheet("to all by donor") firstrow(variables)

use "$folder/dta/tot_contribution_quarter.dta", clear
keep if cand==1
collapse (sum) Amount, by(Year Party)
export excel Year Party Amount using "$folder/out/political_contributions.xlsx", sheet("to candidates by party") firstrow(variables)

use "$folder/dta/tot_contribution_quarter.dta", clear
keep if cand==1
collapse (sum) Amount, by(Year election)
export excel Year election Amount using "$folder/out/political_contributions.xlsx", sheet("to candidates by election") firstrow(variables)

use "$folder/dta/tot_contribution_quarter.dta", clear
keep if cand==1
collapse (sum) Amount, by(Year Status)
export excel Year Status Amount using "$folder/out/political_contributions.xlsx", sheet("to candidates by status") firstrow(variables)

/* How to use "political_contributions.xlsx"?
Variable explanation:
Group		: the relevant infant formula manufacturers of the contribution.
pac=0		: the contribution is made by an employee of the manufacturer.
pac=1		: the contribution is made by a PAC of the manufacturer.
cand=0		: the contribution goes to another PAC including political parties.
cand=1		: the contribution directly goes to a candidate.
election=HR	: the contribution goes to a candidate for the House of Representative.
election=SE	: the contribution goes to a candidate for the Senate.
election=PR	: the contribution goes to a candidate for the President.
RecipCode	:
A two-character code defining the type of recipient. 
For candidates, the first character is party (“D” for Democratic, “R” for Republican, “3” for Independent, Libertarian or third party, “U” for Unknown.) 
The second character is “W” for Winner, “L” for Loser, “I” for incumbent, “C” for Challenger, “O” for “Open Seat”, and “N” for Non-incumbent. 
Incumbent, Challenger and Open Seat are based on CRPICO. “N” is reserved for candidates that are neither in office nor running during the cycle in question.
For party committees, the first character is party and the second character is “P.” For PACs, the first character is “P” and for outside spending groups, "O". 
For both, the second character is “B” for Business, “L” for Labor”, “I” for Ideological, “O” for “Other” and “U” for unknown.
Party extracts the first character from RecipCode.
Status extracts the second character from RecipCode.
*/


log close
