/*************************************************************************************
Version: Oct. 2020
 
This code generates two datasets: 
1) Lobbying by big-6 BMS producers (not limited to BMS-related issue) - lobbying_firm_focused.xlsx
2) BMS-related lobbying expenditure - lobbying_bms_focused.xlsx

The first dataset contains all lobbying outlays spent by big-6 BMS firms and their parents considering M&A history.

The second dataset is constructed as follows.
First, lobbying on BMS-related issues are selected by a string-searching algorithm.
We coded to drop irrelevant observations after reading the described issues.
However, since the descriptions are not very precise, the algorithm does not perfectly work.
To capture other BMS-related lobbying, we read all descriptions of big-6 BMS producers' lobbying and associations of dairy producers' lobbying.
On top of that, since we are particularly interested in lobbying related to intervention (on foreign countries or global institutions),
we read descriptions of lobbying expenditure, which are related to foreign countries.
We focus on countries being intervened in WTO, mentioned in USTR report as having trade barriers, found in news articles for BMS-related regulations.
These pieces of information are then comined to form the main dataset.

In particular, we take the following steps in this code since information on firms, issues, and recipients are stored in different raw data files:
 
1. Import raw data and save as dta      
2. Construct an intermediate dataset of lobbying by BMS firms 
3. Construct an intermediate dataset of lobbying on BMS-related issues 
4. Construct an intermediate dataset of lobbying on country-related issues 
5. Construct an intermediate dataset of lobbying on associations of dairy producers 
6. Complete the final datasets 



Note:
Download Lobbying Data from https://www.opensecrets.org/bulk-data/downloads before running this code.
Text fields are surrounded by pipe character (|), whereas numbers and dates are not.
To import the rawdata into Stata, users have to change all | to " before importing.
Detailed explanations on variables can be found in the Open Data User's Guide (https://www.opensecrets.org/resources/datadictionary/UserGuide.pdf)

************************************************************************************/

log using "$folder/log/lobbying", replace


************* STEP 1: IMPORT RAW DATA ************************************************************
*	Lobbying Data includes 7 tables. Among them, we use 3 tables: agency, issue, and lobbying.
*	All | should be changed to " before importing.
**************************************************************************************************

*** 1. Agency (this file contains IDs assigned to lobbying disclosure and reported recipients)
import delimited "$folder/src/lob_agency.txt", delimiter(comma) clear
rename v# (Uniqid AgencyID Agency)
sort Uniqid
save "$folder/dta/lob_agency.dta", replace

*** 2. Issue (this file contains IDs assigned to lobbying disclosure and reported issues)
import delimited "$folder/src/lob_issue.txt", bindquote(strict) delimiter(comma) colrange(2:5) clear 
rename v# (Uniqid IssueID Issue SpecificIssue)
sort Uniqid
save "$folder/dta/lob_issue.dta",replace

*** 3. Lobbying (this file contains IDs assigned to lobbying disclosure, donors, and the reported amount of expenditure)
import delimited "$folder/src/lob_lobbying.txt", delimiter(comma) bindquote(strict) numericcols(8 15) clear
rename v# (Uniqid Registrant_raw Registrant Isfirm Client_raw Client UltOrg Amount Catcode Source Self IncludeNSFS Use Ind Year Type Typelong Affiliate)

gen quarter=""		// Add quarter information for later use
replace quarter="q1" if strpos(Type, "q1")
replace quarter="q2" if strpos(Type, "q2")
replace quarter="q3" if strpos(Type, "q3")
replace quarter="q4" if strpos(Type, "q4")
egen Quarter=concat(Year quarter) if quarter!=""
drop quarter

drop if Use!="y"	// Only Use=y should be used. For instance, it's "n" if it's modified by following reports.
gen nodc=1		// we generate this variable for later use. nodc=1 is free from double-counting issue 
replace nodc=0 if Ind!="y"	// nodc=0 may be subject to the double-counting (we rename the variable to make it intuitive).

/*
Why do we consider double-counting issue carefully?
In aggregating the lobbied amount, it is important to avoid double-counting.
Double-counting may happen because not only firms that employ lobbyists but also lobbyists are required to report the lobbied amount in the filing period.
For example, if a firm has its in-house lobbying team and hire lobbyists at the same time, 
the firm is required to report all expenditure including that of the lobbyists.
When we add the firm's disclosure and the lobbyists' disclosure, we are double counting the expenditure.
To be free from this issue, CRP recommends to use "Ind=y".
However, instead of dropping Ind!=y (nodc=0) observations, we retain those observations at this stage.
*/
sort Uniqid
save "$folder/dta/lobbying_all.dta", replace


******************* STEP 2: LOBBYING BY BIG-6 BMS FIRMS **********************************
*
* We create a dataset that contains all lobbying outlays spent by big-6 BMS firms considering M&A history.
* This dataset shows the toal lobbying expenditure of big BMS firms and the issues they lobbied for.
* 
* Step 2-1: retain observations related to big-6 BMS firms considering the name of firms.
* Step 2-2: match IDs of the retained observations with "lob_issue.dta" to check issues they lobbied for.
*
******************************************************************************************

*** Step 2-1: Keep BMS firms

gen keep=0 // We use this variable to indicate BMS producers, and reflect M&As
		   // 1: Abbott, 2: Nesle(Gerber), 3: Mead Johnson, 4: Kraft Heinz, 5: Danone, 6: Perrigo
		   
replace UltOrg="Abbott Laboratories" if UltOrg=="Ross Products"
replace keep=1 if UltOrg=="Abbott Laboratories"|UltOrg=="Alere Inc"
replace keep=2 if UltOrg=="Nestle SA"|UltOrg=="Gerber Products Co"|UltOrg=="Novartis AG"|UltOrg=="Pfizer Inc"|UltOrg=="Wyeth"|UltOrg=="American Home Products"
replace keep=3 if UltOrg=="Mead Johnson Nutritional"|strpos(UltOrg,"Reckitt Benckiser")|UltOrg=="Bristol-Myers Squibb"
replace keep=4 if UltOrg=="Kraft Heinz Co"|UltOrg=="Kraft Foods"|UltOrg=="HJ Heinz Co"|UltOrg=="Philip Morris"|UltOrg=="Altria Group"
replace keep=5 if UltOrg=="Groupe Danone"|UltOrg=="Nutritia North America"
replace keep=6 if UltOrg=="Perrigo Co"|UltOrg=="Pbm"

generate Group="Abbott" if keep==1
replace Group="Nestle(Gerber,Wyeth)" if keep==2
replace Group="RB(Mead Johnson)" if keep==3
replace Group="Kraft Heinz" if keep==4
replace Group="Danone" if keep==5
replace Group="Perrigo" if keep==6

*** Drop unnecessary observations based on the time of M&As and spinoffs

replace keep=0 if UltOrg=="Alere Inc"& (Year<2017|Quarter=="2017q1"|Quarter=="2017q2"|Quarter=="2017q3")	// 2007.10

replace keep=0 if UltOrg=="Novartis AG"& Year>2006
replace keep=0 if (UltOrg=="American Home Products"|UltOrg=="Wyeth") &(Year>2009|Quarter=="2009q4")
replace keep=0 if UltOrg=="Pfizer Inc"& (Year<2009|Year>2012|Quarter=="2009q1"|Quarter=="2009q2"|Quarter=="2009q3"|Quarter=="2012q4")

replace keep=0 if UltOrg=="Bristol-Myers Squibb"& (Year>2009|Quarter=="2009q4")		// 2009.11
replace keep=0 if strpos(UltOrg,"Reckitt Benckiser")& (Year<2017|Quarter=="2017q1"|Quarter=="2017q2")		// 2017.6

replace keep=0 if (UltOrg=="Altria Group"|UltOrg=="Philip Morris")& Year>2007	

replace keep=0 if UltOrg=="Perrigo Co"& (Year<2010|Quarter=="2010q1")

keep if keep!=0

*** Step 2-2: Match firms' lobbying data with issues they lobbied for

qui merge 1:m Uniqid using "$folder/dta/lob_issue.dta", keep(match master) 
save "$folder/dta/lobbying_by_firm.dta", replace	// this is an intermediate file that will be used to construct the main dataset (containing nodc=0 obs)


*********************** STEP 3: LOBBYING BY ISSUE *********************************************
*
* Select observations that are related to BMS based on the described issues.
*
* We retain observations containing BMS-related phrases:
* 1. infant formula;
* 2. breastfeeding;
* 3. infant nutrition;
* 4. women, infants, and children.
*
* We intentionally apply broader criteria than we may actually need.
* We do so to capture intervention-related lobbying outlays that would be missed otherwise.
*
* Irrelevant observations are coded to drop out after the manual inspection in Step 6.
*
***********************************************************************************************

use "$folder/dta/lob_issue.dta", clear

gen InfantFormula=0
gen Breastfeeding=0
gen InfantNutrition=0 	// for issues containing "Infant Nutrition" and its variants.
gen InfantAndNutrition=0	// for issues containing "Infant" and "Nutrition". Allow spaces and reverse order. It may catch irrelevant observations as well. But apply this broader filter not to miss interventions.
gen WIC=0

replace InfantFormula=1 if strpos(SpecificIssue, "infant formula")|strpos(SpecificIssue, "Infant formula")|strpos(SpecificIssue, "Infant Formula")|strpos(SpecificIssue, "INFANT FORMULA")
replace Breastfeeding=1 if strpos(SpecificIssue, "breastfeeding")|strpos(SpecificIssue, "Breastfeeding")|strpos(SpecificIssue, "BREASTFEEDING")
replace InfantNutrition=1 if strpos(SpecificIssue, "Infant nutrition")|strpos(SpecificIssue, "infant nutrition")|strpos(SpecificIssue, "Infant Nutrition")|strpos(SpecificIssue, "INFANT NUTRITION")
replace InfantAndNutrition=1 if (strpos(SpecificIssue, "infant")&strpos(SpecificIssue, "nutrition"))|(strpos(SpecificIssue, "Infant")&strpos(SpecificIssue, "nutrition"))|(strpos(SpecificIssue, "infant")&strpos(SpecificIssue, "Nutrition"))|(strpos(SpecificIssue, "Infant")&strpos(SpecificIssue, "Nutrition"))|(strpos(SpecificIssue, "INFANT")&strpos(SpecificIssue, "NUTRITION"))
replace WIC=1 if strpos(SpecificIssue, "Women, Infants, and Children")|strpos(SpecificIssue, "women, infants, and children")|strpos(SpecificIssue, "women, infants and children")|strpos(SpecificIssue, "Women, Infants and Children")
replace WIC=1 if strpos(SpecificIssue, "Women, Infant, and Children")|strpos(SpecificIssue, "women, infant, and children")|strpos(SpecificIssue, "women, infant and children")|strpos(SpecificIssue, "Women, Infant and Children")

gen keep=InfantFormula+Breastfeeding+InfantAndNutrition+WIC
keep if keep!=0
qui merge m:1 Uniqid using "$folder/dta/lobbying_all.dta", keep(match) nogen	// add information including the name of firms and the amount lobbied to the dataset "lob_issue.dta"
sort Uniqid

drop keep

* We classify observations into the narrow and broad group.
* Some observations in the narrow group can be irrelevant. Other than these, all observations in the narrow group will be included in the main dataset.
* Observations in the broad group will be included in the main dataset when they are related to interventions.

replace WIC=1 if strpos(SpecificIssue, "WIC")	// We treat WIC-related observations carefully since many of them are irrelevant.

gen narrow=0
replace narrow=InfantFormula+Breastfeeding+InfantNutrition	// don't count WIC. so it's 0 for only WIC-related obs.
replace narrow=1 if narrow==0&WIC==0						// to capture "nutritional health of infants" or similar issues. Irrelevant observations will be removed manually among these.
replace narrow=1 if narrow>0

save "$folder/dta/lobbying_by_issue", replace	// this is an intermediate file that will be used to construct the second dataset


******************* STEP 3: LOBBYING ON COUNTRY-RELATED ISSUES ************************************************************************************************
*
* We construct an additional dataset to consider intervention on specific countries.
* First, we include countries related to the intervention in the WTO so that we can focus on the intervention related lobbying. 
* We limit the time period of searching for the country names from one year before the first intervention to one year after the last intervention in the WTO.
* Second, we searched for additional intervened countries, which we know from other sources such as USTR National Trade Estimate Report on Foreign Trade Barriers and new articles.
* Specifically, we keep observations if their description includes China(2013-), Canada(2016-), Egypt(2017-), Hong Kong(2012-), Indonesia(2016-2019), Israel(2006-2010),
* Japan(1995-2018), Oman(2006-2008, 2013-2015), Panama(1999-2001), Peru(2004-2006), Saudi Arabia(1996-1999, 2003-2009), Thailand(2014-2018),
* the Philippines (2005-2008), South Korea (2006-2009,2014-2016), Vietnam (2011-2018),  South Africa (2011-2013), India (2003-), United Aram Emirates (2007-2009), 
* Kuwait (2007-2009), Bahrain (2007-2009), Qatar (2007-2009), Russia (2009-2011), Kazakhstan (2015-2018), and Malaysia (2014-2018).
* BMS-irrelevant observations are coded to drop out in Step 6 after the manual inspection.
*
***************************************************************************************************************************************************************

use "$folder/dta/lob_issue.dta", clear

drop if SpecificIssue==""
gen chn=1 if strpos(SpecificIssue,"China")|strpos(SpecificIssue,"china")|strpos(SpecificIssue,"CHINA")
gen can=1 if strpos(SpecificIssue,"Canada")|strpos(SpecificIssue,"canada")|strpos(SpecificIssue,"CANADA")
gen egy=1 if strpos(SpecificIssue,"Egypt")|strpos(SpecificIssue,"egypt")|strpos(SpecificIssue,"EGYPT")
gen hkg=1 if strpos(SpecificIssue,"Hong Kong")|strpos(SpecificIssue,"hong kong")|strpos(SpecificIssue,"HONG KONG")
gen idn=1 if strpos(SpecificIssue,"Indonesia")|strpos(SpecificIssue,"indonesia")|strpos(SpecificIssue,"INDONESIA")
gen isr=1 if strpos(SpecificIssue,"Israel")|strpos(SpecificIssue,"ISRAEL")|strpos(SpecificIssue,"israel")
gen jpn=1 if strpos(SpecificIssue,"Japan")|strpos(SpecificIssue,"japan")|strpos(SpecificIssue,"JAPAN")
gen omn=1 if strpos(SpecificIssue,"Oman")|strpos(SpecificIssue,"OMAN")
gen pan=1 if strpos(SpecificIssue,"Panama")|strpos(SpecificIssue,"panama")|strpos(SpecificIssue,"PANAMA")
gen per=1 if strpos(SpecificIssue,"Peru")|strpos(SpecificIssue,"peru")|strpos(SpecificIssue,"PERU")
gen sau=1 if strpos(SpecificIssue,"Saudi Arabia")|strpos(SpecificIssue,"saudi arabia")|strpos(SpecificIssue,"SAUDI ARABIA")
gen tha=1 if strpos(SpecificIssue,"Thailand")|strpos(SpecificIssue,"thailand")|strpos(SpecificIssue,"THAILAND")
gen phl=1 if strpos(SpecificIssue,"Philippine")|strpos(SpecificIssue,"phillippine")|strpos(SpecificIssue,"PHILIPPINE")
gen vnm=1 if strpos(SpecificIssue,"Vietnam")|strpos(SpecificIssue,"vietnam")|strpos(SpecificIssue,"VIETNAM")|strpos(SpecificIssue,"Viet Nam")|strpos(SpecificIssue,"viet nam")|strpos(SpecificIssue,"VIET NAM")
gen zaf=1 if strpos(SpecificIssue,"South Africa")|strpos(SpecificIssue,"south africa")|strpos(SpecificIssue,"SOUTH AFRICA")
gen kor=1 if strpos(SpecificIssue,"Korea")|strpos(SpecificIssue,"korea")|strpos(SpecificIssue,"KOREA")
gen ind=1 if strpos(SpecificIssue,"India")|strpos(SpecificIssue,"india")|strpos(SpecificIssue,"INDIA")
gen uae=1 if strpos(SpecificIssue,"Arab Emirates")|strpos(SpecificIssue,"arab emirates")|strpos(SpecificIssue,"ARAM EMIRATES")|strpos(SpecificIssue,"UAE")
gen kwt=1 if strpos(SpecificIssue,"Kuwait")|strpos(SpecificIssue,"kuwait")|strpos(SpecificIssue,"KUWAIT")
gen bhr=1 if strpos(SpecificIssue,"Bahrain")|strpos(SpecificIssue,"bahrain")|strpos(SpecificIssue,"BAHRAIN")
gen qat=1 if strpos(SpecificIssue,"Qatar")|strpos(SpecificIssue,"qatar")|strpos(SpecificIssue,"QATAR")
gen rus=1 if strpos(SpecificIssue,"Russia")|strpos(SpecificIssue,"russia")|strpos(SpecificIssue,"RUSSIA")
gen kaz=1 if strpos(SpecificIssue,"Kazkhstan")|strpos(SpecificIssue,"kazkhstan")|strpos(SpecificIssue,"KAZKHSTAN")
gen mys=1 if strpos(SpecificIssue,"Malaysia")|strpos(SpecificIssue,"malaysia")|strpos(SpecificIssue,"MALAYSIA")


replace kor=0 if strpos(SpecificIssue,"North Korea")|strpos(SpecificIssue,"north korea")|strpos(SpecificIssue,"NORTH KOREA")|strpos(SpecificIssue,"N.Korea")|strpos(SpecificIssue,"N. Korea")
replace ind=0 if strpos(SpecificIssue,"Indiana")|strpos(SpecificIssue,"indiana")|strpos(SpecificIssue,"INDIANA")

keep if chn==1|can==1|egy==1|hkg==1|idn==1|isr==1|jpn==1|omn==1|pan==1|per==1|sau==1|tha==1|phl==1|vnm==1|zaf==1|kor==1|ind==1|uae==1|kwt==1|bhr==1|qat==1|rus==1|kaz==1|mys==1

qui merge m:1 Uniqid using "$folder/dta/lobbying_all.dta", keep(match) 

* drop if Year<t-1 or Year>s+1 where t is the first intervention, s is the last intervention in WTO
replace chn=0 if Year<2013
replace can=0 if Year<2016
replace egy=0 if Year<2017
replace hkg=0 if Year<2012
replace idn=0 if Year<2016|Year>2018
replace isr=0 if Year<2006|Year>2010
replace jpn=0 if Year<1995|Year>2018
replace omn=0 if Year<2012|Year>2018
replace pan=0 if Year<1998|Year>2002
replace per=0 if Year<2004|Year>2006
replace sau=0 if Year<1996|Year>2009
replace tha=0 if Year<2014|Year>2018
replace phl=0 if Year<2005|Year>2008
replace vnm=0 if Year<2011|Year>2018
replace zaf=0 if Year<2011|Year>2013
replace kor=0 if Year<2006|(Year>2009&Year<2014)|Year>2016
replace ind=0 if Year<2003
replace uae=0 if Year<2007|Year>2009
replace kwt=0 if Year<2007|Year>2009
replace bhr=0 if Year<2007|Year>2009
replace qat=0 if Year<2007|Year>2009
replace rus=0 if Year<2009|Year>2011
replace kaz=0 if Year<2015|Year>2018
replace mys=0 if Year<2014|Year>2018


keep if chn==1|can==1|egy==1|hkg==1|idn==1|isr==1|jpn==1|omn==1|pan==1|per==1|sau==1|tha==1|phl==1|vnm==1|zaf==1|kor==1|ind==1|uae==1|kwt==1|bhr==1|qat==1|rus==1|kaz==1|mys==1

* drop some observations that are obviously not related to BMS
drop if strpos(UltOrg,"Microsoft")|strpos(UltOrg,"Automotive")|strpos(UltOrg,"Strawberry")|strpos(UltOrg,"Avocado")|strpos(UltOrg,"AFLAC")|strpos(UltOrg,"ZTE")|strpos(UltOrg,"Alibaba")|strpos(UltOrg,"Beef")|strpos(UltOrg,"Nintendo")|strpos(UltOrg,"Motors")|strpos(UltOrg,"Boeing")|strpos(UltOrg,"Fashion")|strpos(UltOrg,"Chevron")|strpos(UltOrg,"Financial")|strpos(UltOrg,"Walnut")|strpos(UltOrg,"Morgan Stanley")|strpos(UltOrg,"IBM Corp")|strpos(UltOrg,"Automobile")|strpos(UltOrg,"Steel")|strpos(UltOrg,"Fisheries")|strpos(UltOrg,"Airline")|strpos(UltOrg,"Visa")|strpos(UltOrg,"Cargill")|strpos(UltOrg,"Zionist")|strpos(UltOrg,"Diamond")|strpos(UltOrg,"Regrigeration")|strpos(UltOrg,"Amnesty")|strpos(UltOrg,"Veterans")|strpos(UltOrg,"Procter")|strpos(UltOrg,"Bluberry")|strpos(UltOrg,"Yahoo")|strpos(UltOrg,"Scientology")|strpos(UltOrg,"Airways")|strpos(UltOrg,"Apparel")|strpos(UltOrg,"Aerospace")|strpos(UltOrg,"Travel")|strpos(UltOrg,"MetLife")|strpos(UltOrg,"Electronics")|strpos(UltOrg,"WH Group")|strpos(UltOrg,"Exxon")|strpos(UltOrg,"Plastics")|strpos(UltOrg,"Starbucks")|strpos(UltOrg,"Software")|strpos(UltOrg,"Biotech")|strpos(UltOrg,"Pork")|strpos(UltOrg,"Tobacco")|strpos(UltOrg,"Film")|strpos(UltOrg,"PayPal")|strpos(UltOrg,"Nuclear")|strpos(UltOrg,"Travel")|strpos(UltOrg,"Auto Workers")|strpos(UltOrg,"Air Line")|strpos(UltOrg,"Amazon")|strpos(UltOrg,"Chemical")|strpos(UltOrg,"Solar")|strpos(UltOrg,"Coca-Cola")|strpos(UltOrg,"Motor")|strpos(UltOrg,"Texas Instrument")|strpos(UltOrg,"Chicken")|strpos(UltOrg,"Rice")|strpos(UltOrg,"Recycling")|strpos(UltOrg,"Corn")|strpos(UltOrg,"Electric")|strpos(UltOrg,"Aluminum")|strpos(UltOrg,"Fitness")|strpos(UltOrg,"Petroleum")|strpos(UltOrg,"Insurer")|strpos(UltOrg,"Insurance")|strpos(UltOrg,"Monsanto")|strpos(UltOrg,"Bank")|strpos(UltOrg,"Christian")|strpos(UltOrg,"Jewish")|strpos(UltOrg,"Bridgestone")|strpos(UltOrg,"Garlic")|strpos(UltOrg,"Chartered")|strpos(UltOrg,"Energy")|strpos(UltOrg,"Sony")|strpos(UltOrg,"Design")|strpos(UltOrg,"Honeywell")|strpos(UltOrg,"Qualcomm")|strpos(UltOrg,"Hilton")|strpos(UltOrg,"Poultry")|strpos(UltOrg,"Christian")|strpos(UltOrg,"Garlic")|strpos(UltOrg,"Nissan")|strpos(UltOrg,"Cisco")|strpos(UltOrg,"Potato")|strpos(UltOrg,"Truck")|strpos(UltOrg,"Mitsubishi")|strpos(UltOrg,"MsterCard")|strpos(UltOrg,"Window")|strpos(UltOrg,"Intellectual")|strpos(UltOrg,"FedEx")|strpos(UltOrg,"Refrigeration")|strpos(UltOrg,"Roundtable")|strpos(UltOrg,"Silicon")|strpos(UltOrg,"Oracle")|strpos(UltOrg,"Railroads")|strpos(UltOrg,"Haier")|strpos(UltOrg,"Cotton")|strpos(UltOrg,"Cummins")|strpos(UltOrg,"Footwear")|strpos(UltOrg,"AFL-CIO")|strpos(UltOrg,"Grain")|strpos(UltOrg,"Construction")|strpos(UltOrg,"Meat")|strpos(UltOrg,"Fig Growers")|strpos(UltOrg,"Outdoor")|strpos(UltOrg,"Technologies")|strpos(UltOrg,"Human Rights")|strpos(UltOrg,"Computing")|strpos(UltOrg,"Beet Sugar")|strpos(UltOrg,"Paper")|strpos(UltOrg,"Cherry")|strpos(UltOrg,"Chase")|strpos(UltOrg,"Textile")|strpos(UltOrg,"Parcel")|strpos(UltOrg,"Wood Products")|strpos(UltOrg,"Cosmetology")|strpos(UltOrg,"Fig Advisor")|strpos(UltOrg,"Cetacean")|strpos(UltOrg,"Hallmark")|strpos(UltOrg,"Automaker")|strpos(UltOrg,"MasterCard")|strpos(UltOrg,"Nike")|strpos(UltOrg,"Panasonic")|strpos(UltOrg,"Bluberry")|strpos(UltOrg,"Tyson Foods")|strpos(UltOrg,"Property Rights")|strpos(UltOrg,"Caterpillar")|strpos(UltOrg,"insurance")|strpos(UltOrg,"Mine Workers")|strpos(UltOrg,"Capital Management")|strpos(UltOrg,"Automaker")|strpos(UltOrg,"Elanco Animal")|strpos(UltOrg,"Texas Cattle")|strpos(UltOrg,"NYC Human Resources")|strpos(UltOrg,"Pflug")|strpos(UltOrg,"Family Research Council")|strpos(UltOrg,"eHealth")|strpos(UltOrg,"Fraternal Order")|strpos(UltOrg,"NARAL Pro")|strpos(UltOrg,"Qarizada")|strpos(UltOrg,"Wildlife")|strpos(UltOrg,"Airline")|strpos(UltOrg,"Google")|strpos(UltOrg,"Home Builders")|strpos(UltOrg,"Realty")|strpos(UltOrg,"Glen Raven Mills")|strpos(UltOrg,"MillerCoors")|strpos(UltOrg,"Tibet")|strpos(UltOrg,"Vernell")|strpos(UltOrg,"Atlas Air")|strpos(UltOrg,"Purolite")|strpos(UltOrg,"Weyerhaeuser")|strpos(UltOrg,"Glen Raven Mills")|strpos(UltOrg,"Estate")|strpos(UltOrg,"NAACP")|strpos(UltOrg,"Eli Lilly")|strpos(UltOrg,"Education Fund")|strpos(UltOrg,"AMR Corp")|strpos(UltOrg,"Crisis Group")|strpos(UltOrg,"Conservation")|strpos(UltOrg,"Cranberry")|strpos(UltOrg,"Sugar")|strpos(UltOrg,"Blangiardo")|strpos(UltOrg,"United Continental")|strpos(UltOrg,"Tribe")|strpos(UltOrg,"Tribal")|strpos(UltOrg,"Indians")|strpos(UltOrg,"AT&T")|strpos(UltOrg,"Samsung")|strpos(UltOrg,"ACE Ltd")|strpos(UltOrg,"Blueberry")|strpos(UltOrg,"Lumber")|strpos(UltOrg,"National Turkey")|strpos(UltOrg,"Wal-Mart")|strpos(UltOrg,"Tata Group")|strpos(UltOrg,"Carpenter")|strpos(UltOrg,"HP Inc")|strpos(UltOrg,"Levi St")|strpos(UltOrg,"Oilseed")|strpos(UltOrg,"Motion Picture")|strpos(UltOrg,"Campbell")|strpos(UltOrg,"UBS")|strpos(UltOrg,"Warner")|strpos(UltOrg,"Pizza")|strpos(UltOrg,"Hewlett")|strpos(UltOrg,"Whirlpool")|strpos(UltOrg,"DuPont")|strpos(UltOrg,"Target Corp")|strpos(UltOrg,"Retail")|strpos(UltOrg,"Dell")|strpos(UltOrg,"Micron")|strpos(UltOrg,"Lonestar")|strpos(UltOrg,"Novartis")|strpos(UltOrg,"ANSAC")|strpos(UltOrg,"Bayer")|strpos(UltOrg,"iRobot")|strpos(UltOrg,"Glaxo")|strpos(UltOrg,"News Corp")|strpos(UltOrg,"3M")|strpos(UltOrg,"Timken")|strpos(UltOrg,"AstraZeneca")|strpos(UltOrg,"Becton")|strpos(UltOrg,"Home Depot")|strpos(UltOrg,"Pet Food")|strpos(UltOrg,"Siemens")|strpos(UltOrg,"Herballife")|strpos(UltOrg,"Zekelman")|strpos(UltOrg,"Entertainment")|strpos(UltOrg,"Communications")|strpos(UltOrg,"SSAB")|strpos(UltOrg,"Forest")

keep if IssueID=="TRD"

sort Uniqid
save "$folder/dta/lobbying_on_cnty", replace		// this is an intermediate file that will be used to construct the second dataset


*************** STEP 5: LOBBYING BY ASSOCIATIONS OF DAIRY PRODUCERS ***************
*
* We construct an additional dataset to capture more intervention-related lobbying expenditure.
* The dataset generated by this step consists of all lobbying expenditure by a set of the associations of dairy producers.
* Irrelevant observations are coded to drop out in Step 6.
*
**********************************************************************************

use "$folder/dta/lobbying_all.dta", clear

keep if strpos(UltOrg, "Milk Producer")|strpos(UltOrg, "Dairy Farmer")|strpos(UltOrg, "Dairymen")|strpos(UltOrg, "Dairy Food")|strpos(UltOrg, "National All-Jersey")|strpos(UltOrg, "Dairy Producer")|strpos(Client, "Dairy Coalition")|strpos(UltOrg, "Infant Nutrition Council")|strpos(UltOrg, "Fonterra Cooperative")|strpos(UltOrg, "Pennyslvania Farm")
qui merge 1:m Uniqid using "$folder/dta/lob_issue.dta", keep(match)
drop if SpecificIssue==""|SpecificIssue=="NONE"

sort Uniqid
save "$folder/dta/lobbying_by_assn", replace		// this is an intermediate file that will be used to construct the second dataset


*************** STEP 6: FINAL DATASETS *******************************************
*
* Step 6-1: We merge all datasets by IDs and find interventions.
* Step 6-2: We check if nodc=0 observations are exposed to double-counting
* 			The second dataset "lobbying_bms_focused.xlsx" is created.
* Step 6-3: "lobbying_firm_focused.xlsx" is created.
*
**********************************************************************************

*** Step 6-1: Merge and find interventions *****************************************
*
* To generate the second dataset, we first merge the intermediate datasets we generated.
* Then, intervention-related observations are marked after the manual inspection of the described issues.
* Irrelevant observations are dropped at this step.
*
************************************************************************************

use "$folder/dta/lobbying_by_issue.dta", clear

qui merge m:m Uniqid Issue using "$folder/dta/lobbying_by_firm.dta", nogen
qui merge m:m Uniqid Issue using "$folder/dta/lobbying_on_cnty.dta", nogen
qui merge m:m Uniqid Issue using "$folder/dta/lobbying_by_assn.dta", nogen

drop if SpecificIssue==""
replace Issue="X" if Issue!="Trade"		// Among the issues that firms voluntarily reported as relevant field, we are interested in trade-related disclosures.
sort Uniqid Issue
collapse (first) Issue Client UltOrg Amount Year Quarter nodc narrow, by(Uniqid SpecificIssue)
replace Issue="Others" if Issue!="Trade"
sort Year Quarter Uniqid

gen irrelevant=0 if narrow==1	// There are some irrelevant observations with narrow=1. We should remove those observations.

* The followings are not related to BMS but captured because of the phrases. 
replace irrelevant=1 if strpos(SpecificIssue,"infant mortality")&strpos(SpecificIssue,"Black parenting and nutrition")
replace irrelevant=1 if strpos(SpecificIssue,"Infantry Regiment")&strpos(SpecificIssue,"Veterans Nutrition")
replace irrelevant=1 if strpos(SpecificIssue,"infant mortality")&strpos(SpecificIssue,"Nutrition's Role")
replace irrelevant=1 if Client=="Natl Assn of Pediatric Nurse Assoc"&strpos(SpecificIssue,"Protecting Our Infants Act")

gen intervention=0				// Observations related to interventions are of our interest.

* On general issue
replace intervention=1 if strpos(SpecificIssue,"Infant formula regulat")&Issue=="Trade"
replace intervention=1 if strpos(SpecificIssue,"infant nutrition marketing")&Issue=="Trade"
replace intervention=1 if strpos(SpecificIssue,"Infant Nutrition")&Issue=="Trade"

* On WHO
replace intervention=1 if strpos(SpecificIssue,"World Health Organization initiatives")|strpos(SpecificIssue,"World Health Organization Initiatives")
replace intervention=1 if strpos(SpecificIssue,"World Health Organization")&strpos(SpecificIssue,"Infant Nutrition")
replace intervention=1 if strpos(SpecificIssue,"World Health Organization")&strpos(SpecificIssue,"U.S. delegation")
replace intervention=1 if strpos(SpecificIssue,"WHO")&strpos(SpecificIssue,"dairy products for children under")
replace intervention=1 if strpos(SpecificIssue,"WHO")&strpos(SpecificIssue,"marketing of milk products")
replace intervention=1 if strpos(UltOrg,"Infant")&strpos(SpecificIssue,"WHO Guidance on Marketing")
replace intervention=1 if strpos(SpecificIssue,"WHO")&strpos(SpecificIssue,"dairy and trade")
replace intervention=1 if strpos(SpecificIssue,"World Health Organization")&strpos(SpecificIssue,"Birth to 24 Months")
replace intervention=1 if strpos(SpecificIssue,"World Health Organization")&strpos(SpecificIssue,"Birth to 24 months")
replace intervention=1 if strpos(SpecificIssue,"World Health")&strpos(SpecificIssue,"infant")&strpos(SpecificIssue,"feeding")
replace intervention=1 if strpos(SpecificIssue,"WHO Guidance")&strpos(SpecificIssue,"Promotion")&strpos(SpecificIssue,"Food for Infants")
replace intervention=1 if strpos(SpecificIssue,"WHO Guidance")&strpos(SpecificIssue,"Formula")

* On Korea
replace intervention=1 if strpos(SpecificIssue,"Korea infant formula market access")

* On the Philippines
replace intervention=1 if strpos(SpecificIssue,"Philippine")&(strpos(SpecificIssue,"infant formula")|strpos(SpecificIssue,"Infant Formula")|strpos(SpecificIssue,"Milk Code"))

* On India and China
replace intervention=1 if Year<2016&(UltOrg=="Abbott Laboratories"|UltOrg=="Mead Johnson Nutritional")&strpos(SpecificIssue,"India")&(strpos(SpecificIssue,"issue")|strpos(SpecificIssue,"Issue"))
replace intervention=1 if strpos(SpecificIssue,"Dairy trade issues with India, Russia, Mexico and China")	
replace intervention=1 if UltOrg=="National Milk Producers Federation"&strpos(SpecificIssue,"dairy certification")&strpos(SpecificIssue,"India")
replace intervention=1 if UltOrg=="Mead Johnson Nutritional"&strpos(SpecificIssue,"food safety issues re: China")
replace intervention=1 if UltOrg=="Abbott Laboratories"&strpos(SpecificIssue,"US-China food safety cooperation")

* On Canada
replace intervention=1 if strpos(SpecificIssue,"Canada dairy supply management")&Year>2015	
replace intervention=1 if strpos(SpecificIssue,"U.S. dairy product access to Canadian markets")&Year>2015	
replace intervention=1 if strpos(SpecificIssue,"Canad")&strpos(SpecificIssue,"milk pricing")&Year>2015	
replace intervention=1 if strpos(SpecificIssue,"Canada")&strpos(SpecificIssue,"dairy policy")&Year>2015	
replace intervention=1 if strpos(SpecificIssue,"Canada")&strpos(SpecificIssue,"class pricing")&strpos(SpecificIssue,"dairy")&Year>2015	
replace intervention=1 if strpos(SpecificIssue,"Canad")&strpos(SpecificIssue,"Class 7")&strpos(SpecificIssue,"dairy")	&Year>2015
replace intervention=1 if strpos(SpecificIssue,"Canada")&strpos(SpecificIssue,"dairy")&strpos(SpecificIssue,"trade")&Year>2015
replace intervention=1 if strpos(SpecificIssue,"Canada")&strpos(SpecificIssue,"limit")&strpos(SpecificIssue,"dairy")&Year>2015
replace intervention=1 if strpos(SpecificIssue,"Canadian barrier")&strpos(SpecificIssue,"dairy products")&Year>2015
replace intervention=1 if strpos(SpecificIssue,"Non-tariff")&strpos(SpecificIssue,"dairy in Canada")&Year>2015
replace intervention=1 if strpos(SpecificIssue,"market access")&strpos(SpecificIssue,"dairy")&strpos(SpecificIssue,"Canada")&Year>2015
replace intervention=1 if strpos(SpecificIssue,"Canada")&strpos(SpecificIssue,"dairy")&strpos(SpecificIssue,"strategy")&Year>2015
replace intervention=1 if UltOrg=="Dairy Farmers of America"&strpos(SpecificIssue,"Canada")&strpos(SpecificIssue,"")&Year>2015
replace intervention=1 if UltOrg=="Edge Dairy Farmer Cooperative"&strpos(SpecificIssue,"Canada")&strpos(SpecificIssue,"Non-tariff barriers")&Year>2015

* On Japan
replace intervention=1 if strpos(SpecificIssue,"Japan")&strpos(SpecificIssue,"dairy")&(strpos(SpecificIssue,"Trans Pacific Partnership")|strpos(SpecificIssue,"Trans-Pacific Partnership"))

keep if (narrow==1&irrelevant==0)|intervention==1

* Categorize donors into 3 sectors.
* Industry, health/science and others (1*: industry, 2*: health/science, 3: others)
* (10: firms, 11: industrial associations, 20: Medical centers, professional medical assn, and nurses, 21: Health related NPOs, 22: Science related NPOS, 23: WIC related NPOs)

gen category=3
replace category=10 if UltOrg=="Abbott Laboratories"|UltOrg=="Nestle SA"|UltOrg=="Perrigo Co"|strpos(UltOrg,"Mead Johnson")|UltOrg=="Ross Products"|UltOrg=="Kellogg Co"|strpos(UltOrg,"Gerber Products")|strpos(UltOrg,"Coca-Cola")|strpos(UltOrg,"Wal-Mart")|strpos(UltOrg,"Bristol-Myers")|strpos(UltOrg,"Kraft Foods")|strpos(UltOrg,"GenCorp")|strpos(UltOrg,"Dean Foods")|strpos(UltOrg,"Medela")|strpos(UltOrg,"Kroger Co")|strpos(UltOrg,"Martek Bio")|strpos(UltOrg,"Harvest Hill")|strpos(UltOrg,"Management")|strpos(UltOrg,"Plum Organics")|strpos(UltOrg,"Royal DSM")|strpos(UltOrg, "Fonterra Cooperative")|strpos(UltOrg, "Kraft Heinz")
replace category=11 if strpos(UltOrg,"Infant Nutrition Council")|strpos(UltOrg,"International Dairy Foods")|strpos(UltOrg,"Juice Products")|strpos(UltOrg,"National Potato")|strpos(UltOrg,"Grocery Manufacturer")|strpos(UltOrg,"National Grocer")|strpos(UltOrg,"Food Marketing")|strpos(UltOrg,"Natural Products")|strpos(UltOrg,"Farm Bureau")|strpos(UltOrg,"Vegetable")|strpos(UltOrg,"Fresh Produce")|strpos(UltOrg,"Organic Trade")|strpos(UltOrg,"Responsible Nutrition")|strpos(UltOrg,"Grocer")|strpos(UltOrg,"Canned")
replace category=11 if strpos(UltOrg, "Milk Producer")|strpos(UltOrg, "Dairy Farmer")|strpos(UltOrg, "Dairymen")|strpos(UltOrg, "Dairy Food")|strpos(UltOrg, "National All-Jersey")|strpos(UltOrg, "Dairy Producer")|strpos(Client, "Dairy Coalition")|strpos(UltOrg, "Infant Nutrition Council")|strpos(UltOrg, "Pennyslvania Farm")
replace category=20 if strpos(UltOrg,"Pediatric")|strpos(UltOrg,"Family Physician")|strpos(UltOrg,"Lactation Consultant")|strpos(UltOrg,"Dental")|strpos(UltOrg,"Nurses")|strpos(UltOrg,"Medical")|strpos(UltOrg,"Obstetricians")|strpos(UltOrg,"Fetal Medicine")|strpos(UltOrg,"Academy")|strpos(UltOrg,"Heart Assn")|strpos(UltOrg,"Clinic")|strpos(UltOrg,"Public Health")|strpos(UltOrg,"UPMC")
replace category=21 if strpos(UltOrg,"March of Dimes")|strpos(UltOrg,"Health Plan")|strpos(UltOrg,"Child Health Programs")|strpos(UltOrg,"Healthcare")|strpos(UltOrg,"Alliance for Children")|strpos(UltOrg,"Nemours")|strpos(UltOrg,"Center for Reproductive")
replace category=22 if strpos(UltOrg,"Scholars Strategy")|strpos(UltOrg,"Center for Science")|strpos(UltOrg,"Institute for Science")
replace category=23 if strpos(UltOrg,"California WIC")|strpos(UltOrg,"National WIC Assn")

gen sector="Health&Science"
replace sector="Industry" if category==10|category==11
replace sector="Others" if category==3

save "$folder/dta/lob_int.dta", replace	// intermediate file that will be finalized after checking the double-counting issue.


*** Step 6-2: Check double-counting and generate "output_lobbying.xlsx"

***********************************************************************************************
*
* 1. Double-counting
* This step allows observations which do not cause double-counting to remain in our dataset even though they are subject to double-counting in total lobbying of a firm.
* To do so, we create an intermediate file which contains the maximum amount that is not subject to double-counting by organizations for each filing period.
* Suppose, for instance, we find an observation with nodc=0 that indicates Abbott's lobbying of $20000 via a lobbyst X in 2008q1.
* Then this observation shouldn't be included when computing the total amount lobbied by Abbott in 2008q1.
* It's because Abbott may report the aggregate amount lobbied in 2008q1 in another report by adding their spending via the lobbyist X.
* In this regard, lobbying by BMS firms should retain only nodc=1 observations.
* However, our main dataset does not keep all lobbying expenditure of firms.
* We keep observations that are relevant to BMS. 
* Then, if there's no observation with nodc=1 that Abbott lobbied larger than $20000 in 2008q1 in our dataset, adding this observation does not cause double-counting issue.
* It can happen when we capture lobbyist-reported issue as relevant, whereas we don't capture the Abbott's report that includes this expenditure as relevant in 2008q1.
*
* In other words, since firms are not required to report all issues they lobbied unlike the aggregate expenditure, 
* it is possible that we miss some BMS-related lobbying just because they are not reported by the firm even if they are reported by lobbyists. 
* To capture these observations, we add nodc=0 observations only if the same firm does not file greater or equal amount in the same filing period. 
*
* 2. Export necessary data as an excel file (output_lobbying.xlsx) 
*
* The "issue_added" sheet includes all described issues in disclosures.
* The "collapsed" sheet includes the lobbied amount that can be used to aggregate.
* The "recipients" sheet shows all agencies lobbying expenditures were spent.
*
***********************************************************************************************

replace Quarter=string(Year)+"q1-q4" if Quarter==""		// Firms reported annually before 2008.
keep if nodc==1
collapse (max) Amount, by(Year Quarter UltOrg)
rename Amount Max

save "$folder/dta/max.dta", replace		// intermediate file

use "$folder/dta/lob_int.dta", clear
qui merge m:1 Year Quarter UltOrg using "$folder/dta/max.dta", keep(master match)

gen summable=0		// this variable indicates whether the observation can can be used or not
replace summable=1 if nodc==1		
replace summable=1 if nodc==0&_merge==1		// no other reports of the same firm are found in the same period
replace summable=1 if nodc==0&(Amount>Max)	// other nodc=1 reports are found but are with smaller amount, which implies no double-counting
replace summable=1 if nodc==0&intervention==1&Amount==0	// not subject to double-counting since Amount=0. Keep this to see the description of issues.

save "$folder/dta/lob_int_max.dta", replace		// intermediate file with Max added

keep if summable==1
export excel Uniqid Year Quarter Client UltOrg Amount Issue SpecificIssue intervention sector using "$folder/out/lobbying_bms_focused.xlsx", sheet("issue_added") firstrow(variables) replace

replace Issue="X" if Issue!="Trade"
sort Uniqid Issue
collapse (first) Year Quarter Client UltOrg Amount Issue sector (max) intervention, by(Uniqid)
replace Issue="Others" if Issue!="Trade"
 
export excel Uniqid Year Quarter Client UltOrg Amount Issue intervention sector using "$folder/out/lobbying_bms_focused.xlsx", sheet("collapsed") firstrow(variables)

qui merge 1:m Uniqid using "$folder/dta/lob_agency.dta", keep(matched) nogen
replace Agency="Undetermined" if AgencyID==240
export excel Uniqid Year Quarter UltOrg Agency Amount using "$folder/out/lobbying_bms_focused.xlsx", sheet("recipients") firstrow(variables)


*** Step 6-3: generate "lobbying_by_firm.xlsx" for big-6 lobbying
*
* The "issue_added" sheet includes all described issues in disclosures.
* The "collapsed" sheet includes the lobbied amount that can be used to aggregate.
* The "recipients" sheet shows all agencies lobbying expenditures were spent.
* The "lobbyists" sheet shows lobbyists involved in by disclosures.
*
***********************************************************************************************

use "$folder/dta/lobbying_by_firm.dta", clear

keep if nodc==1		// keep only relevant observations to compute total
export excel Uniqid Year Quarter UltOrg Amount Issue SpecificIssue using "$folder/out/lobbying_firm_focused.xlsx", firstrow(variables) sheet("issue_added") replace

replace Issue="X" if Issue!="Trade"
sort Uniqid Issue
collapse (first) Year Quarter Client UltOrg Amount Issue, by(Uniqid)
replace Issue="Others" if Issue!="Trade"
export excel Uniqid Year Quarter UltOrg Amount Issue  using "$folder/out/lobbying_firm_focused.xlsx", firstrow(variables) sheet("collapsed")

qui merge 1:m Uniqid using "$folder/dta/lob_agency.dta", keep(match) nogen
replace Agency="Undetermined" if AgencyID==240
export excel Uniqid Year Quarter UltOrg Agency Amount using "$folder/out/lobbying_firm_focused.xlsx", firstrow(variables) sheet("recipients")


log close
